import { CliHandlerArgv } from '@done-coding/cli-utils';
import { CommandModule } from 'yargs';
import type { CompileOptions } from '@done-coding/cli-template';

export declare interface AddOptions {
    /**
     * 组件名
     */
    name: string;
}

/** 组件配置 */
export declare interface Config {
    /** 组件系列 */
    series: string;
    /** 组件名排除列表 */
    nameExcludes: string[];
    /** 组件目录 */
    componentDir: string;
    /** 配置列表 */
    list: ConfigListItem[];
}

/** 列表item */
export declare interface ConfigListItem {
    /** 入口文件 */
    entry: TemplateConfig;
    /** 索引文件 */
    index?: TemplateConfig;
}

/** 作为子命令创建 */
export declare const crateAsSubcommand: () => CommandModule<{}, {}>;

export declare const handler: (command: SubcommandEnum, argv: CliHandlerArgv<any>) => Promise<void>;

export declare interface RemoveOptions {
    /**
     * 组件名
     */
    name?: string;
}

/** 子命令枚举 */
export declare enum SubcommandEnum {
    /** 新增组件 */
    ADD = "add",
    /** 移除组件 */
    REMOVE = "remove",
    /** 展示列表 */
    LIST = "list"
}

/** 模版配置 */
export declare type TemplateConfig = TemplateConfigInputByPath | TemplateConfigInputByData;

/** 模版配置完整 */
export declare type TemplateConfigFull = Pick<CompileOptions, "input" | "inputData" | "output">;

/** 模版配置输入数据 */
export declare type TemplateConfigInputByData = Pick<CompileOptions, "inputData" | "output">;

/** 模版配置输入路径 */
export declare type TemplateConfigInputByPath = Pick<CompileOptions, "input" | "output">;

export { }
